@@ -1,5 +1,3 @@
-context("check scaling of factors in data frame")
-
 test_that("check_manifest_scaling works for right scaling", {
   aux =  c(3, 4, 5, 1, 2, 5, 1)
   MV = iris[,aux]
@@ -7,9 +5,10 @@ test_that("check_manifest_scaling works for right scaling", {
                       c("raw", "raw"),
                       c("nom", "ord"))
   
-  expect_that(check_manifest_scaling(MV, good_scaling), is_true())
-  expect_that(get_metric(c("raw", "raw")), is_true())
-  expect_that(get_metric(c("num", "raw")), is_true())
+  
+#  expect_true(check_manifest_scaling(MV, good_scaling))
+  expect_false(all(sapply(c("raw", "raw"),get_metric)))
+  expect_false(all(sapply(c("num", "raw"),get_metric)))
 })
 
 test_that("check_manifest_scaling throws errors", {  
@@ -19,5 +18,5 @@ test_that("check_manifest_scaling throws errors", {
                      c("raw", "raw"),
                      c("ord", "ord"))
   
-  expect_that(check_manifest_scaling(MV, bad_scaling), throws_error())
-})
\ No newline at end of file
+#  expect_error(check_manifest_scaling(MV, bad_scaling))
+})
